@@ -16,6 +16,7 @@ from .subcommands import (
     assetbundleinfo,
     asshader,
     il2cpp,
+    malioc,
 )
 
 _VERSION_FILE_NAME = "version.txt"
@@ -72,6 +73,7 @@ def main(_args=None):
         Command("ab", assetbundleinfo, "extract unity asset bundle information"),
         Command("il2cpp", il2cpp, "extract unity il2cpp information"),
         Command("asshader", asshader, "simplify asset studio shader preview data"),
+        Command("malioc", malioc, "mail offline compile"),
     ]
 
     subparser = parser.add_subparsers(title="sub commands", dest="subcommand")
